// Mounting plate for Celestron star pointer finderscope

module flat_triangle(h, w, b) //Create a triangle, with thickness h, and sides w and b
		translate([0,0,h/2])
		linear_extrude(height = h, center = true, convexity = 10, twist = 0)
		polygon(points=[[0,0],[w,0],[0,b]], paths=[[0,1,2]]);

module trapezoid(thickness, top, bottom, height) //Create a trapezoid, with thickness h, top side top, bottom bottom, and height h
		translate([0,0,thickness/2])
		linear_extrude(height = thickness, center = true, convexity = 10, twist = 0)
		polygon(points=[[top/2,0],[-top/2,0],[-bottom/2,height],[bottom/2,height]], paths=[[0,1,2,3]]);

module sight_mount(length, width, height, hole_dia, hole_dis, align, trap_bot, trap_top, trap_h, trap_len) //Create a mounting plate for a sight
	difference() {
		// Create the mounting plate with fastening triangle and alignment spikes
		union() {
			// Base plate
			cube([width,length,height]);
			// Alignment triangles
			translate([width/2,-(align/2)]) rotate([0,0,45]) flat_triangle(height, align, align);
			translate([width/2,length+(align/2)]) rotate([0,0,-135]) flat_triangle(height, align, align);
			// Mount
			// -0.01 factor used to create manifold unit
			translate([width/2, (length-trap_len)/2, 2*height-0.01]) rotate(a=[-90,0,0])trapezoid(trap_len, trap_bot, trap_top, trap_h);
		}

		// Posistion the mounting holes
		translate([hole_dis,hole_dis]) cylinder(height+1,(hole_dia/2),(hole_dia/2));
		translate([width-hole_dis,hole_dis]) cylinder(height+1,(hole_dia/2),(hole_dia/2));
		translate([hole_dis,length-hole_dis]) cylinder(height+1,(hole_dia/2),(hole_dia/2));
		translate([width-hole_dis,length-hole_dis]) cylinder(height+1,(hole_dia/2),(hole_dia/2));
	}

// Create the actual mount
sight_mount(70, 54, 5, 3.8, 5, 20, 16, 10, 5, 50);